==> haskell-crypton-x509-validation-1.6.12-36-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-crypton-x509-validation.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 crypton-x509-validation
version:              1.6.12
visibility:           public
id:                   crypton-x509-validation-1.6.12-FML16ZSXtXu1mGpWqziDF2
key:                  crypton-x509-validation-1.6.12-FML16ZSXtXu1mGpWqziDF2
license:              BSD-3-Clause
copyright:            Vincent Hanquez <vincent@snarc.org>
maintainer:           Kazu Yamamoto <kazu@iij.ad.jp>
author:               Vincent Hanquez <vincent@snarc.org>
stability:            experimental
homepage:             https://github.com/kazu-yamamoto/crypton-certificate
synopsis:             X.509 Certificate and CRL validation
description:          X.509 Certificate and CRL validation. please see README
category:             Data
abi:                  3234fbe74b1948325458fd4faab5e153
exposed:              True
exposed-modules:      Data.X509.Validation
hidden-modules:
    Data.X509.Validation.Signature Data.X509.Validation.Fingerprint
    Data.X509.Validation.Cache Data.X509.Validation.Types

import-dirs:
    /usr/lib/ghc-9.2.8/site-local/crypton-x509-validation-1.6.12

library-dirs:
    /usr/lib/ghc-9.2.8/site-local/crypton-x509-validation-1.6.12

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-crypton-x509-validation
hs-libraries:         HScrypton-x509-validation-1.6.12-FML16ZSXtXu1mGpWqziDF2
depends:
    asn1-encoding-0.9.6-FcrLQyuBErx9Mp9LnC4HFp
    asn1-types-0.3.4-7qnzOE20uxRE1ObGqmOcZX base-4.16.4.0
    bytestring-0.11.4.0 containers-0.6.5.1
    crypton-0.34-8r4ML9HZlNH1XNh1g7ZkM1
    crypton-x509-1.7.6-3jVr56DvxggKC8dzi7hjps
    crypton-x509-store-1.6.9-LJAbSla6YJgJFrIQhO3NWX
    data-default-class-0.1.2.0-Kt3ErptCt5hHHi8l61h1Gp
    hourglass-0.2.12-BJnGrPpEnFv6qsbjXcI2fh
    memory-0.18.0-Hvum6HaH78UJG59LYyNLK1 mtl-2.2.2
    pem-0.2.4-4o5872XElj3E57MBFQ3n3Z

haddock-interfaces:
    /usr/share/doc/haskell-crypton-x509-validation/html/crypton-x509-validation.haddock

haddock-html:         /usr/share/doc/haskell-crypton-x509-validation/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-crypton-x509-validation-1.6.12-37-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-crypton-x509-validation.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 crypton-x509-validation
version:              1.6.12
visibility:           public
id:                   crypton-x509-validation-1.6.12-5ir02qqEbozC7HVG40x18d
key:                  crypton-x509-validation-1.6.12-5ir02qqEbozC7HVG40x18d
license:              BSD-3-Clause
copyright:            Vincent Hanquez <vincent@snarc.org>
maintainer:           Kazu Yamamoto <kazu@iij.ad.jp>
author:               Vincent Hanquez <vincent@snarc.org>
stability:            experimental
homepage:             https://github.com/kazu-yamamoto/crypton-certificate
synopsis:             X.509 Certificate and CRL validation
description:          X.509 Certificate and CRL validation. please see README
category:             Data
abi:                  f414dbf2fdf637aac84887701698016c
exposed:              True
exposed-modules:      Data.X509.Validation
hidden-modules:
    Data.X509.Validation.Signature Data.X509.Validation.Fingerprint
    Data.X509.Validation.Cache Data.X509.Validation.Types

import-dirs:
    /usr/lib/ghc-9.2.8/site-local/crypton-x509-validation-1.6.12

library-dirs:
    /usr/lib/ghc-9.2.8/site-local/crypton-x509-validation-1.6.12

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-crypton-x509-validation
hs-libraries:         HScrypton-x509-validation-1.6.12-5ir02qqEbozC7HVG40x18d
depends:
    asn1-encoding-0.9.6-Hr1Ipf9yW86DaIXpOYUIp0
    asn1-types-0.3.4-GbTPtd35bL4C5ny7uqD9as base-4.16.4.0
    bytestring-0.11.4.0 containers-0.6.5.1
    crypton-0.34-Fpqy3C4emJMgOhmqvFm9N
    crypton-x509-1.7.6-Kxd5ozJflcyItODVP5K1kF
    crypton-x509-store-1.6.9-2TuahvNnDETHjKzNDronvp
    data-default-class-0.1.2.0-Kt3ErptCt5hHHi8l61h1Gp
    hourglass-0.2.12-20Yo0REaTlI6KNFkOv5Auh
    memory-0.18.0-Hvum6HaH78UJG59LYyNLK1 mtl-2.2.2
    pem-0.2.4-9drnxNPWKlpnYxy9dAwDu

haddock-interfaces:
    /usr/share/doc/haskell-crypton-x509-validation/html/crypton-x509-validation.haddock

haddock-html:         /usr/share/doc/haskell-crypton-x509-validation/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
